# MCP Community is Open-Source

At Mirascope, we're strong believers in the power of open-source software.
We've built MCP Community with the intention of making it a community-driven project, and we're excited to see where it goes.

As an open-source project, MCP Community makes it so:

- You can see exactly what's going on under the hood and how it works.
- You can [self-host](../self-hosting) MCP Community on your own servers and customize it to your heart's content.
- You can [contribute](https://github.com/Mirascope/mcp-community/tree/main/CONTRIBUTING.md) to the project.

## License

This project is licensed under the terms of the [Apache License 2.0](https://github.com/Mirascope/mcp-community/blob/main/LICENSE).